@@ -41,6 +41,7 @@ import bson.objectid
 import bson.son
 
 import transaction
+
 import zope.interface
 import zope.location.location
 from zope.security.proxy import removeSecurityProxy
@@ -56,6 +57,17 @@ from m01.mongo.tm import ensureMongoTransaction
 _marker = object()
 
 
+def getObjectIdByKey(key):
+    """Returns ObjectId for given key (string)"""
+    if PY2 and isinstance(key, newstr):
+        # ObjectId requires a simple str
+        key_str = "{}".format(key)
+    else:
+        # Standard conversion in Python 3
+        key_str = str(key)
+    return bson.objectid.ObjectId(key_str)
+
+
 class MongoObjectAware(object):
     """Offers _moid (mongo object id) referencable for IMongoObject as _oid"""
 
@@ -1025,13 +1037,8 @@ class MongoStorageBase(MongoMappingBase):
             return True
         else:
             try:
-                if PY2 and isinstance(key, newstr):
-                    key_str = "{}".format(key)  # ObjectId requires a simple str
-                else:
-                    key_str = str(key)  # Standard conversion in Python 3
-
-                data = self.doFindOne(self.collection,
-                    {'_id': bson.objectid.ObjectId(key_str)})
+                _id = getObjectIdByKey(key)
+                data = self.doFindOne(self.collection, {'_id': _id})
                 if data is not None:
                     return True
             except(pymongo.errors.InvalidId, TypeError) as e:
@@ -1067,13 +1074,8 @@ class MongoStorageBase(MongoMappingBase):
         obj = self._cache_loaded.get(key)
         if obj is None:
             try:
-                if PY2 and isinstance(key, newstr):
-                    key_str = "{}".format(key)  # ObjectId requires a simple str
-                else:
-                    key_str = str(key)  # Standard conversion in Python 3
-
-                data = self.doFindOne(self.collection,
-                    {'_id': bson.objectid.ObjectId(key_str)})
+                _id = getObjectIdByKey(key)
+                data = self.doFindOne(self.collection, {'_id': _id})
                 if data is None:
                     raise KeyError(key)
             except(pymongo.errors.InvalidId, TypeError) as e:
