@@ -14,6 +14,8 @@
 """
 $Id:$
 """
+from __future__ import absolute_import
+
 __docformat__ = "reStructuredText"
 
 import zope.interface
@@ -23,6 +25,7 @@ from m01.mongo import interfaces
 from m01.mongo import base
 
 
+@zope.interface.implementer(interfaces.IMongoContainer)
 class MongoContainer(base.MongoContainerBase, contained.Contained):
     """Mongo storage based container supporting item with __name__.
     
@@ -32,4 +35,3 @@ class MongoContainer(base.MongoContainerBase, contained.Contained):
     if you like to store such MongoContainer in ZODB.
     """
 
-    zope.interface.implements(interfaces.IMongoContainer)
