@@ -14,6 +14,9 @@
 """
 $Id:$
 """
+from __future__ import absolute_import
+from builtins import object
+from zope.interface import implementer
 __docformat__ = "reStructuredText"
 
 import os.path
@@ -46,6 +49,8 @@ from m01.mongo.fieldproperty import MongoGeoPointProperty
 from m01.mongo.fieldproperty import MongoObjectProperty
 
 
+VERSION = '3.6.23'
+
 # mongo db name used for testing
 TEST_DB_NAME = 'm01_mongo_testing'
 TEST_COLLECTION_NAME = 'test'
@@ -91,12 +96,12 @@ class TestCase(unittest.TestCase):
         if self.iface is not None:
             return self.iface
         msg = 'Subclasses has to implement getTestInterface()'
-        raise NotImplementedError, msg
+        raise NotImplementedError(msg)
 
     def getTestClass(self):
         if self.klass is not None:
             return self.klass
-        raise NotImplementedError, 'Subclasses has to implement getTestClass()'
+        raise NotImplementedError('Subclasses has to implement getTestClass()')
 
     def getTestData(self):
         return {}
@@ -318,10 +323,12 @@ def setUpStubMongo(test=None):
     """Setup pymongo client as test client and setup a real empty mongodb"""
     host = 'localhost'
     port = 45017
+    version = VERSION
     tz_aware = True
     sandBoxDir = os.path.join(os.path.dirname(__file__), 'sandbox')
     import m01.stub.testing
-    m01.stub.testing.startMongoServer(host, port, sandBoxDir=sandBoxDir)
+    m01.stub.testing.startMongoServer(host, port, sandBoxDir=sandBoxDir,
+        version=version)
     # setup pymongo.MongoClient as test client
     global _testClient
     _testClient = pymongo.MongoClient(host, port, tz_aware=tz_aware)
@@ -384,10 +391,10 @@ class ISampleSubItem(interfaces.IMongoSubItem):
         required=True)
 
 
+@zope.interface.implementer(ISampleSubItem)
 class SampleSubItem(item.MongoSubItem):
     """Sample sub item."""
 
-    zope.interface.implements(ISampleSubItem)
 
     dumpNames = ['text']
 
@@ -465,10 +472,10 @@ class ISampleStorageItem(ITestSchema, interfaces.IMongoStorageItem):
         required=True)
 
 
+@zope.interface.implementer(ISampleStorageItem)
 class SampleStorageItem(item.MongoStorageItem, base.MongoUpdateMixin):
     """Sample item."""
 
-    zope.interface.implements(ISampleStorageItem)
 
     title = MongoFieldProperty(ISampleStorageItem['title'])
     description = MongoFieldProperty(ISampleStorageItem['description'])
@@ -489,10 +496,10 @@ class ISampleStorage(interfaces.IMongoStorage):
     """Sample storage interface."""
 
 
+@zope.interface.implementer(ISampleStorage)
 class SampleStorage(TestCollectionMixin, storage.MongoStorage):
     """Sample storage."""
 
-    zope.interface.implements(ISampleStorage)
 
     def __init__(self):
         pass
@@ -515,10 +522,10 @@ class ISampleContainerItem(ITestSchema, interfaces.IMongoContainerItem,
         required=True)
 
 
+@zope.interface.implementer(ISampleContainerItem)
 class SampleContainerItem(item.MongoContainerItem):
     """Sample item."""
 
-    zope.interface.implements(ISampleContainerItem)
 
     __name__ = MongoFieldProperty(ISampleContainerItem['__name__'])
     title = MongoFieldProperty(ISampleContainerItem['title'])
@@ -540,10 +547,10 @@ class ISampleContainer(interfaces.IMongoContainer):
     """Sample container interface."""
 
 
+@zope.interface.implementer(ISampleContainer)
 class SampleContainer(TestCollectionMixin, container.MongoContainer):
     """Sample container."""
 
-    zope.interface.implements(ISampleContainer)
 
     def load(self, data):
         """Load data into the right mongo item."""
@@ -555,10 +562,10 @@ class ISampleMongoObject(ITestSchema, interfaces.IMongoObject):
     """Sample mongo object interface."""
 
 
+@zope.interface.implementer(ISampleMongoObject)
 class SampleMongoObject(item.MongoObject):
     """Sample mongo object."""
 
-    zope.interface.implements(ISampleMongoObject)
 
     title = MongoFieldProperty(ISampleMongoObject['title'])
     description = MongoFieldProperty(ISampleMongoObject['description'])
@@ -639,10 +646,10 @@ class IDocument(interfaces.IMongoContainerItem):
         description=u'Text',
         required=True)
 
+@zope.interface.implementer(IDocument)
 class Document(item.MongoContainerItem):
     """Sample sub item."""
 
-    zope.interface.implements(IDocument)
 
     dumpNames = ['text']
 
@@ -658,6 +665,7 @@ class IEmployer(interfaces.IMongoContainerItem, interfaces.IMongoContainer):
         description=u'Name',
         required=True)
 
+
 class Employer(item.MongoContainerItem, container.MongoContainer):
     """Mongo company item and Employer container"""
 
@@ -751,10 +759,10 @@ class IGeoSample(interfaces.IMongoContainerItem):
         required=False)
 
 
+@zope.interface.implementer(IGeoSample)
 class GeoSample(item.MongoContainerItem):
     """Geo sample item"""
 
-    zope.interface.implements(IGeoSample)
 
     name = MongoFieldProperty(IGeoSample['name'])
     lonlat = MongoGeoLocationProperty(IGeoSample['lonlat'])
@@ -777,10 +785,10 @@ class IGeoPointSample(interfaces.IMongoContainerItem):
         required=False)
 
 
+@zope.interface.implementer(IGeoPointSample)
 class GeoPointSample(item.MongoContainerItem):
     """GeoPoint sample item"""
 
-    zope.interface.implements(IGeoPointSample)
 
     name = MongoFieldProperty(IGeoPointSample['name'])
     lonlat = MongoGeoPointProperty(IGeoPointSample['lonlat'])
